<?php
/*
 *
 * Copyright(c) 2000-2011 LOCKON CO.,LTD. All Rights Reserved.
 *
 * http://www.lockon.co.jp/
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

/**
 * プラグインのメインクラス
 *
 * @package PointHistory
 * @author LOCKON CO.,LTD.
 * @version $Id: $
 */
class PointHistory extends SC_Plugin_Base {

    /**
     * コンストラクタ
     */
    public function __construct(array $arrSelfInfo) {
        parent::__construct($arrSelfInfo);
    }
    
    /**
     * インストール
     * installはプラグインのインストール時に実行されます.
     * 引数にはdtb_pluginのプラグイン情報が渡されます.
     *
     * @param array $arrPlugin plugin_infoを元にDBに登録されたプラグイン情報(dtb_plugin)
     * @return void
     */
    function install($arrPlugin) {
        //$this->lfCreateTable();

        // 必要なファイルをコピーします.
        if(copy(PLUGIN_UPLOAD_REALDIR . "PointHistory/templates/point_history.tpl", TEMPLATE_REALDIR . "../admin/customer/point_history.tpl") === false) print_r("失敗");
        if(copy(PLUGIN_UPLOAD_REALDIR . "PointHistory/logo.png", PLUGIN_HTML_REALDIR . "PointHistory/logo.png") === false) print_r("失敗");
    }

    /**
     * アンインストール
     * uninstallはアンインストール時に実行されます.
     * 引数にはdtb_pluginのプラグイン情報が渡されます.
     * 
     * @param array $arrPlugin プラグイン情報の連想配列(dtb_plugin)
     * @return void
     */
    function uninstall($arrPlugin) {
        $objQuery =& SC_Query_Ex::getSingletonInstance();

        if(SC_Utils_Ex::deleteFile(TEMPLATE_REALDIR . "admin/customer/point_history.tpl") === false); // TODO エラー処理
        if(SC_Utils_Ex::deleteFile(PLUGIN_HTML_REALDIR . "PointHistory") === false); // TODO エラー処理
    }
    
    /**
     * 稼働
     * enableはプラグインを有効にした際に実行されます.
     * 引数にはdtb_pluginのプラグイン情報が渡されます.
     *
     * @param array $arrPlugin プラグイン情報の連想配列(dtb_plugin)
     * @return void
     */
    function enable($arrPlugin) {
        // nop
    }

    /**
     * 停止
     * disableはプラグインを無効にした際に実行されます.
     * 引数にはdtb_pluginのプラグイン情報が渡されます.
     *
     * @param array $arrPlugin プラグイン情報の連想配列(dtb_plugin)
     * @return void
     */
    function disable($arrPlugin) {
        // nop
    }

    /**
     * 処理の介入箇所とコールバック関数を設定
     * registerはプラグインインスタンス生成時に実行されます
     * 
     * @param SC_Helper_Plugin $objHelperPlugin 
     */
    function register(SC_Helper_Plugin $objHelperPlugin) {
        $objHelperPlugin->addAction('LC_Page_Admin_Customer_Edit_action_before', array($this, 'lfSetPointHistory'));
    }

    /**
     * 読み込むテンプレート設定および、データの取得
     */
    function lfSetPointHistory($objPage){
        $template_dir = PLUGIN_UPLOAD_REALDIR . 'PointHistory/templates/';
        $objPage->tpl_mainpage = $template_dir. 'point_history.tpl'; 
        $customer_id = 0;
        if(!empty($_POST['customer_id'])){
            $customer_id = $_POST['customer_id'];
        }elseif(!empty($_POST['edit_customer_id'])){
            $customer_id = $_POST['edit_customer_id'];
        }elseif(!empty($_POST['search_customer_id'])){
            $customer_id = $_POST['search_customer_id'];
        }
        if($customer_id > 0){
            $objPage->history = $this->lfGetPointHistory($customer_id);
        }
    }

    /**
     * ポイント履歴の取得 
     * キャンセル以外の受注を取得する
     */
    function lfGetPointHistory($customer_id){
        $objQuery =& SC_Query_Ex::getSingletonInstance();
        $objQuery->setOrder('update_date DESC');
        $history = $objQuery->select('order_id, use_point, add_point, status, update_date', "dtb_order", "customer_id = ? AND status != ?", array($customer_id, ORDER_CANCEL));
        foreach($history as $key => $val){
            if($val['status'] == 5){
                $history[$key]['sum_point'] = $val['add_point'] - $val['use_point'];
            }else{
                $history[$key]['sum_point'] = 0 - $val['use_point'];
            }
        }
        return $history;  
    }

}
?>
